//Copyright © mSIGNIA, Incorporated, 2007.  All rights reserved.
//
//Software is protected by one or more of U.S. Patent No. 9,559,852, 9294448, 8,817,984,
//international patents and others pending. For more information see www.mSIGNIA.com.  User agrees
//that they will not them self, or through any affiliate, agent or other third-party, entity or
//other business structure remove, alter, cover or obfuscate any copyright notices or other
//proprietary rights notices of mSIGNIA or its licensors.  User agrees that they will not them
//self, or through any affiliate, agent or other third party, entity or other business structure
//(a) reproduce, sell, lease, license or sublicense this software or any part thereof, (b)
//decompile, disassemble, re-program, reverse engineer or otherwise attempt to derive or modify
//this software in whole or in part, (c) write or develop any derivative software or any other
//software program based upon this software, (d) provide, copy, transmit, disclose, divulge, or
//make available to, or permit use of this software by any third party or entity or machine without
//software owner's prior written consent, (e) circumvent or disable any security or other
//technological features or measures used by this software.
//
//  BuildEnvironment.swift
//  ThreeDSStoreDemo
//
//  Created by Drew Pitchford on 6/26/17.
//  Copyright © 2017 mSignia. All rights reserved.
//

import Foundation

class BuildEnvironment {
    
    // MARK: - User Entered Info
    static var paysimEmail: String? {
        set {
            UserDefaults.standard.setValue(newValue, forKey: "paysim_email")
        }
        get {
            return UserDefaults.standard.string(forKey: "paysim_email")
        }
    }
    
    static var paysimPassword: String? {
        set {
            UserDefaults.standard.setValue(newValue, forKey: "paysim_password")
        }
        get {
            return UserDefaults.standard.string(forKey: "paysim_password")
        }
    }
    
    static var baseURL: String {
        get {
            guard let defaultBaseURL = Bundle.main.infoDictionary?["BASE_URL"] as? String else {
                fatalError("Base url not configured in info.plist")
            }
            
            print("Live base url: \(defaultBaseURL)")
            let userEnteredURL = UserDefaults.standard.string(forKey: "user_entered_url")
            return userEnteredURL ?? defaultBaseURL
        }
        set {
            UserDefaults.standard.setValue(newValue, forKey: "user_entered_url")
        }
    }
    
    static var licenseKey: String? {
        set {
            UserDefaults.standard.setValue(newValue, forKey: "usdk_license_key")
        }
        get {
            return UserDefaults.standard.string(forKey: "usdk_license_key")
        }
    }
    
    static var accountNumber: String {
        set {
            UserDefaults.standard.setValue(newValue.isEmpty ? Defaults.acctNumber : newValue, forKey: "acct_number")
        }
        get {
            UserDefaults.standard.string(forKey: "acct_number") ?? Defaults.acctNumber
        }
    }
    
    static var crashReportingDSN: String {
        set {
            UserDefaults.standard.set(newValue.isEmpty ? Defaults.sentryDSN : newValue, forKey: "sentry_dsn")
        }
        get {
            UserDefaults.standard.string(forKey: "sentry_dsn") ?? Defaults.sentryDSN
        }
    }
    
    static var activeAPIInterface: APIInterface {
        set {
            UserDefaults.standard.setValue(newValue.rawValue, forKey: "active_interface")
        }
        get {
            return APIInterface(rawValue: UserDefaults.standard.string(forKey: "active_interface") ?? "simplified") ?? .simplified
        }
    }
}
