//
//  Constants.swift
//  ThreeDS-Sample
//
//  Created by Drew Pitchford on 5/14/20.
//  Copyright © 2020 mSignia. All rights reserved.
//

import Foundation
import UIKit

struct GlobalConstants {
    struct JsonKeys {}
    struct WebPaths {}
    struct AppConstants {}
    struct UI {}
    struct DS {}
}

typealias UIConstants = GlobalConstants.UI
extension GlobalConstants.UI {
    struct Radii {
        static let `default`: CGFloat = 10
    }
}

typealias DSConstants = GlobalConstants.DS
extension GlobalConstants.DS {
    static let ecName = "MSIGNIA_MOCK_DS_EC"
    static let ecKeyID = "de7655be-3d6f-4802-9d68-c36a9d23e71c"
    static let ecKey = "{\"kty\":\"EC\",\"crv\":\"P-256\",\"x\":\"7YTOG_nT8NtzC7sgQDEEsbkFX6VEXdzXgpoU0FD7gRY\",\"y\":\"Th1ej6HF0K9yVg3DM0K6zQrxERBSoX597LqadlIq77o\"}"
    static let rsaName = "MSIGNIA_MOCK_DS_RSA"
    static let rsaKeyID = "de7655be-3d6f-4802-9d68-c36a9d23e71c"
    static let rsaKey = "{\"kty\":\"RSA\",\"e\":\"AQAB\",\"kid\":\"de7655be-3d6f-4802-9d68-c36a9d23e71c\",\"n\":\"4Uko-Z2ESFV5IUXunK08ouSziFz_OfuRR9H4woBdMbAeyAq0-V5o36tCtiNVYgF2Oi1jBgmEIxIMH9y-W_Mn0OoiwzV7eQj4tc0q5RM9RzYEMoRCK-0YU4nFzRlDSFQOIPEkEWihPHujyY32qBDyMsl0ctlq5EN-F77u9wCvoxU9OLM3dlAE42dNrbrHWOnpeWg41kk63AUowZlA7QE52Tgd_hyaHAy4oQtgp1_-l-SPIAKIoAF-5Ibiss4Y1Wah1RSvDz69UMgHoqc_cvWG9kTPMtkFoIwW8ta2jhGzvhoNf2X1o2excBLKlWT3hIwGfnw8oYRDlINTZIuTGLc0cw\"}"
    
    static let cert = """
    -----BEGIN CERTIFICATE-----
    MIID4zCCAsugAwIBAgIBATANBgkqhkiG9w0BAQsFADB7MQswCQYDVQQGEwJVUzEL
    MAkGA1UECBMCVE4xEDAOBgNVBAoTB01TSUdOSUExDDAKBgNVBAsTA1JORDEXMBUG
    A1UEAxMOTVNJR05JQSBSTkQgQ0ExJjAkBgkqhkiG9w0BCQEWF3BhdmxvLmx5c292
    QG1zaWduaWEuY29tMB4XDTE5MTExMzA3MzYwMFoXDTI5MTExMzA3MzYwMFowezEL
    MAkGA1UEBhMCVVMxCzAJBgNVBAgTAlROMRAwDgYDVQQKEwdNU0lHTklBMQwwCgYD
    VQQLEwNSTkQxFzAVBgNVBAMTDk1TSUdOSUEgUk5EIENBMSYwJAYJKoZIhvcNAQkB
    FhdwYXZsby5seXNvdkBtc2lnbmlhLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEP
    ADCCAQoCggEBAPSn+PdwUVXYq5IQN+vrcxM3WfR5Xpgb3OpIRkka863duH0j3Uh/
    poaFxnp/j0dGbefYaKaXGZSFX/E3FWaAFGKHV2Lbt4uxYkJx4Fa2gXsBxqdOd4Li
    aqSRSZXPtYMqoMbCOQj4lqtthBNe5BDX6/1HDJELLo8sxnIyfwxgbome3s9e6Rpz
    p+M9XgOtfyuSzPhzY0bWeBrHDzPcKkxQgKZeywlgApCPPfoYEvBDfzGbNns4yA+v
    sqYGDcctplQceUG6EFN68qbmy3CzV8zQMHFkHqIJ/l1V5RlGT9b5QhNVhu4MJo//
    W8LaA6vdyyqPnS7Hbvp6JklkMVxJJhWl0t8CAwEAAaNyMHAwDwYDVR0TAQH/BAUw
    AwEB/zAdBgNVHQ4EFgQU443mM7cesLlNiq01jfVfyJ7Rh1gwCwYDVR0PBAQDAgEG
    MBEGCWCGSAGG+EIBAQQEAwIABzAeBglghkgBhvhCAQ0EERYPeGNhIGNlcnRpZmlj
    YXRlMA0GCSqGSIb3DQEBCwUAA4IBAQBOY7ETJ0MyrQ44MYNbkGI7fIij5oxM0In0
    Z4ZT5NCA1p3fJP/PV8oxONE+7ix1GlCw8RR59L2VQGkg4I2vSj0DHqpuPf3u86Fm
    gZtkhcF41dlWSic1B5oaA610iglITgu/gyZrC+r6RHGIKfyLX+u8YGc6WfI8g/ED
    aVQcnq/PZAEeZtBGiZdYxnIQhIOxV04nFmtOjSyyMt5NXMHFLHRnewSI6tojcFm2
    lm6WMZQXFqGyvkxjmPQXFFBCupAAPIkm0lIIvZqtvLOOqmU7et4Oy5pihyaHjg67
    cdmlv/p990e7YYfzdQSKezWrdwXW4EAGBTyuAZ67a5XCOUi17JZU
    -----END CERTIFICATE-----
    """
}

typealias WebPaths = GlobalConstants.WebPaths
extension GlobalConstants.WebPaths {
    static let supportedVersions = "/api/v6/supported-versions"
    static let auth = "/api/v6/auth"
}

typealias Defaults = GlobalConstants.AppConstants.DefaultValues
extension GlobalConstants.AppConstants {
    struct DefaultValues {
        static let acctNumber = "5578386966810305"
        static let sentryDSN = ""
        static let apiInterface = "simplified"
        static let uiDelay = 0.1
    }
}

typealias JsonKeys = GlobalConstants.JsonKeys
extension GlobalConstants.JsonKeys {
    
    static let payloadKey = "payload"
    
    static let addressKey = "addresses"
    struct Address {
        
        static let fullName = "fullName"
        static let addressLine1 = "addressLine1"
        static let addressLine2 = "addressLine2"
        static let city = "city"
        static let state = "state"
        static let phone = "phone"
        static let countryCode = "cc"
        static let country = "country"
        static let zip = "zipCode"
        static let type = "type"
        static let defaultKey = "isDefault"
    }
    
    struct App {
     
        static let authToken = "3ds_demo_store_auth_token"
        static let userID = "3ds_demo_store_user_id"
        static let userEmail = "3ds_demo_store_user_email"
        static let userPassword = "3ds_demo_store_user_password"
    }
    
    struct AuthRequest {
        
        static let email = "email"
        static let type = "type"
        static let sdkAppID = "sdkAppID"
        static let sdkTransID = "sdkTransID"
        static let encryptionScheme = "encryptionScheme"
        static let sdkEncData = "sdkEncData"
        static let sdkEphemPubKey = "sdkEphemPubKey"
        static let addNewCard = "addNewCard"
        static let sdkReferenceNumber = "sdkReferenceNumber"
        static let deviceRenderOptions = "deviceRenderOptions"
        static let acctNumber = "acctNumber"
        static let acctType = "acctType"
        static let addrMatch = "addrMatch"
        static let homePhone = "homePhone"
        static let merchantName = "merchantName"
        static let threeDSRequestorAuthenticationInd = "threeDSRequestorAuthenticationInd"
        static let mobilePhone = "mobilePhone"
        static let workPhone = "workPhone"
        static let purchaseAmount = "purchaseAmount"
        static let purchaseCurrency = "purchaseCurrency"
        static let purchaseDate = "purchaseDate"
        static let purchaseExponent = "purchaseExponent"
        static let messageExtension = "messageExtension"
        static let threeDSRequestorPriorAuthenticationInfo = "threeDSRequestorPriorAuthenticationInfo"
        static let threeDSDemoRenderingType = "threeDSDemoRenderingType"
        static let threeDSDemoScenario = "threeDSDemoScenario"
        static let billAddrCity = "billAddrCity"
        static let billAddrCountry = "billAddrCountry"
        static let billAddrLine1 = "billAddrLine1"
        static let billAddrLine2 = "billAddrLine2"
        static let billAddrPostCode = "billAddrPostCode"
        static let billAddrState = "billAddrState"
        static let cardExpiryDate = "cardExpiryDate"
        static let cardholderName = "cardholderName"
        static let shipAddrCity = "shipAddrCity"
        static let sdkMaxTimeout = "sdkMaxTimeout"
        static let shipAddrCountry = "shipAddrCountry"
        static let shipAddrLine1 = "shipAddrLine1"
        static let shipAddrLine2 = "shipAddrLine2"
        static let shipAddrPostCode = "shipAddrPostCode"
        static let shipAddrState = "shipAddrState"
        static let demoCouponCode = "demoCouponCode"
        static let threeDSServerTransID = "threeDSServerTransID"
        static let acsSignedContent = "acsSignedContent"
        static let acsRefNumber = "acsReferenceNumber"
        static let acsTransID = "acsTransID"
        static let transStatus = "transStatus"
        static let messageCategory = "messageCategory"
        static let threeDSRequestorNPAInd = "threeDSRequestorNPAInd"
        static let directoryServerID = "directoryServerID"
    }
    
    struct AuthenticationResponse {
        
        static let errorCode = "errorCode"
        static let sdkTransID = "sdkTransID"
    }
    
    static let cardKey = "cards"
    struct Card {
        
        static let name = "name"
        static let cardNumber = "cardNumber"
        static let cvv = "cvv"
        static let type = "type"
        static let image = "imageUrl"
        static let expirationMonth = "expirationMonth"
        static let expirationYear = "expirationYear"
        static let isDefault = "isDefault"
        static let description = "description"
        static let cardID = "cardId"
        static let duplicate = "duplicate"
    }
    
    struct CardCompany {
        
        static let imageUrl = "imageUrl"
        static let name = "name"
    }
    
    struct Error {
        
        static let errorCode = "errorCode"
        static let errorMessage = "errorMessage"
        static let status = "status"
    }
    
    struct Login {
        
        static let email = "email"
        static let password = "password"
        static let token = "token"
        static let user = "user"
        static let expiration = "expiration"
    }
    
    struct Product {
        
        static let id = "id"
        static let name = "name"
        static let price = "price"
        static let imageUrl = "imageUrl"
        static let salePrice = "salePrice"
        static let salePercentage = "salePercentage"
    }
    
    struct ResponseObject {
        
        static let payload = "payload"
        static let products = "products"
        static let content = "content"
        static let cardCompanies = "cardCompanies"
    }
    
    struct SubscriptionRequest {
        
        static let threeDSServerTransID = "threeDSServerTransID"
        static let lineItems = "lineItems"
        static let acctNumber = "acctNumber"
        
        struct LineItem {
            
            static let quantity = "quantity"
            static let paymentAmount = "paymentAmount"
            static let paymentCount = "paymentCount"
        }
    }
    
    static let userKey = "user"
    struct User {
        
        static let id = "id"
        static let email = "email"
        static let addresses = "addresses"
        static let cards = "cards"
        static let password = "password"
        static let confirmPassword = "confirmPassword"
        static let defaultCardType = "defaultCardType"
    }
    
    struct Verification {
        
        struct Response {
            
            static let success = "success"
        }
    }
}
