//
//  DirectoryServerInfo.swift
//  ThreeDS-Sample
//
//  Created by Drew Pitchford on 7/21/21.
//  Copyright © 2021 mSignia. All rights reserved.
//

import Foundation

enum DirectoryServerInfo: String {
    
    // MARK: - Cases
    case discover = "A000000152"
    case visa = "VISA(RSA)"
    case mastercard = "138576"
    case amex = "A000000025"
    case msigniaEC = "MSIGNIA_MOCK_DS_EC"
    case msigniaRSA = "MSIGNIA_MOCK_DS_RSA"
    case jcb = "A000000065"
    
    // Demo Only
    case demoMC = "DEMO-MC-RSA-DS_REF_NUMBER"
    case demoVisa = "DEMO-VISA-RSA-DS_REF_NUMBER"
    case demoDiscover = "DEMO-DISCOVER-RSA-DS_REF_NUMBER"
    case demoAmex = "DEMO-AMEX-RSA-DS_REF_NUMBER"
    case demoCB = "DEMO-CB-RSA-DS_REF_NUMBER"
    case demoJCB = "DEMO-JCB-RSA-DS_REF_NUMBER"
    
    // MARK: - Properties
    var keyID: String {
        switch self {
        case .msigniaRSA, .demoMC, .demoVisa, .demoDiscover, .demoAmex, .demoCB, .demoJCB:
            return "de7655be-3d6f-4802-9d68-c36a9d23e71c"
        default:
            return ""
        }
    }
    
    var publicKey: String {
        switch self {
        case .discover:
            return "{\"kty\":\"RSA\",\"e\":\"AQAB\",\"kid\":\"0e0b8d78-afd1-4132-b0be-dade5ac7c879\",\"n\":\"uuojTTe2qmXnitLT8Oh2M7dGor0GfA73uI6TKHCjfuSY3dj5aMJsfUAfgdhOEyrWsRTR2hOXQ21a8qBiN_S9IYKWhVrLK6JatZDZyWDItldSwHbK_dT1wu25ryyelpEnKBtCA7myBsUs1hwHx5iHm5Wf5mswWgjv1bizr2xRnKj7qfW1BGkdyteJ6CCC9F7kkXllLcpHmMaXxU6Mg0PsCovcft9O9Sbhc-6cRC-cL1xI5hZ-_yGUK4hP1rl82fJRNGyAm-p96Yidnt3JB5LU-MRCgZqkpGimXES44-GSIWS2vNPWsWjCrfEp2j4iO5M_E-liNK1Nv2SRokeePCwfHQ\"}"
                
        case .visa:
            return "{\"kty\":\"RSA\",\"e\":\"AQAB\",\"n\":\"u3epfcCDV2POl354s-bdG4LNkeVCL4aYr_iKYokmuDaauZKqN1f9XizvtkLwP5sEixfLWBJmJZJlKjLe9mKvonli9DBTdhnbKW_gsLHRMpECQjnkDYbuKyD9Ho7-R4rJ8Z6SCNHs8x_3uyEvJ5-Z-BT5uEogrqXP9HB2b_5xQNGIZ3xrKAclNG3yjTB90wLyeYryBGcJCP6A0BFUkHMd_KP-NC24bn207CcGCl209eWmd6BwWlT5LZYkyHs7YM-pvJozRs2Lhkq4FyzM_M6h_75VB6Z5f5lAlSn1UF01AvKgPy3ADPZPD-GGXtmTLzQBOdoeHqH9ekVj96O9UZlnAw\"}"
                
        case .amex:
            return "{\"kty\":\"RSA\",\"e\":\"AQAB\",\"kid\":\"e1406ba4-46c1-42b5-8f3f-fb1d79096173\",\"n\":\"pZ-wiGCfWdBcPY4C8e6WKopy5OkOxbaaraRdYb2qxq_MKqzkDY9MMV03j02i49FcZ1RzrY1UnIn0dm6g45UzM3BXYGM-MXowWMEi_fRwsi2PHCS_riYmwUkqqKu6vVHlYBt4Lg6ZLrxViUunCqsBw1-bQo2KgPfr4nY4TJUzfBg-kqJldJ6wGoLpJir841sLhiQ6zgEqeVXlpIQ0jDJTHPvS37FPhY2WXtzT9BoWxIfeCXs7Qlm4HQE3zKvONCiBjMLSfTgXuqjoC0oTauzBMJqxOEThMMSnyw6DqEhta20xuw7fYmhucpdSOaQ3rWUy23KWJDs9CFeAUlyn2Cmt2w\"}"
                
        case .mastercard:
            return "{\"kty\":\"RSA\",\"e\":\"AQAB\",\"n\":\"2EPLWFIep-_pa0mXKEcljP9tSwTLC0yXf4NayVjh9-FmmOjN84Y2j0Hx8eSNfxCyqbu4pewiVZYWsZz95XzxASh16NGq7qOlYVBizUg4q3ONaomfzaeaUGp9usSh2VaSYjdcU0-2fhB2TWpyPOZ3_r9-895X91BJz2fY4mbJI1RVaTxVJI-ueSLHA13-GT90biIigy00fjT0WTDouSMJP-tafVYpeLzGClhlUSflfOZkVv9Uw2J6MgHPDyIj19RHLGGxaa46EZ_hMONlPh-mi3bB_0fecMTNXopzzxWwG_qGvCPpV08Iim2AvNDhWLrZ9D2t4Vsckrej3PBIHpnZmw\"}"
                
        case .msigniaEC:
            return "{\"kty\":\"EC\",\"crv\":\"P-256\",\"x\":\"7YTOG_nT8NtzC7sgQDEEsbkFX6VEXdzXgpoU0FD7gRY\",\"y\":\"Th1ej6HF0K9yVg3DM0K6zQrxERBSoX597LqadlIq77o\"}"
                
        case .msigniaRSA, .demoMC, .demoVisa, .demoDiscover, .demoAmex, .demoCB, .demoJCB:
            return "{\"kty\":\"RSA\",\"e\":\"AQAB\",\"kid\":\"de7655be-3d6f-4802-9d68-c36a9d23e71c\",\"n\":\"4Uko-Z2ESFV5IUXunK08ouSziFz_OfuRR9H4woBdMbAeyAq0-V5o36tCtiNVYgF2Oi1jBgmEIxIMH9y-W_Mn0OoiwzV7eQj4tc0q5RM9RzYEMoRCK-0YU4nFzRlDSFQOIPEkEWihPHujyY32qBDyMsl0ctlq5EN-F77u9wCvoxU9OLM3dlAE42dNrbrHWOnpeWg41kk63AUowZlA7QE52Tgd_hyaHAy4oQtgp1_-l-SPIAKIoAF-5Ibiss4Y1Wah1RSvDz69UMgHoqc_cvWG9kTPMtkFoIwW8ta2jhGzvhoNf2X1o2excBLKlWT3hIwGfnw8oYRDlINTZIuTGLc0cw\"}"
    
        case .jcb:
            return "{\"kty\":\"RSA\",\"e\":\"AQAB\",\"kid\":\"b91e0f25-eeb9-41bc-b995-f9a6d2008928\",\"n\":\"ry2AZpW0Bipj5rOwzK-3O2qi7N6oW6TGoz1czS_JRDdeFtNZ82SeC_gS63iRds0ErrmEfSzawA9eSjVhnwNNqW3YM4jRfAO9ZXzmW_Tpyz_n7g-la-SY7ZjqdFVl4SIXu2jO8IHwcjqJy_IwzS_ekYmOVTDjLVRvR49MuKn_skxFRepRkLuOFZe2VdicdMu8PFboep44IgWzL5oUcqVL6AR_UVtiaAGEhTnQLJdzsx71U797ur5nbzt9hl5EeTuW570kQ_uM3MSbvrJzJO62mYAVGo7mqJace0rnz5E9Uc0VPV-HOqH3Q9tDuB5gf2BBIlfG3dPTWam6CipmtjIg0Q\"}"
        }
    }
    
    var caCert: String {
        switch self {
        case .discover:
            return """
                -----BEGIN CERTIFICATE-----
                MIIEoTCCA4mgAwIBAgICAI0wDQYJKoZIhvcNAQEFBQAwgZwxCzAJBgNVBAYTAlVT
                MREwDwYDVQQIEwhJbGxpbm9pczETMBEGA1UEBxMKUml2ZXJ3b29kczEkMCIGA1UE
                ChMbRGlzY292ZXIgRmluYW5jaWFsIFNlcnZpY2VzMRkwFwYDVQQLExBQYXltZW50
                IFNlcnZpY2VzMSQwIgYDVQQDExtleHRlbnRlZHJvb3QucHJvdGVjdGJ1eS5jb20w
                HhcNMTQwMzE5MDAwMDAwWhcNMzQxMjMxMDAwMDAwWjCBnDELMAkGA1UEBhMCVVMx
                ETAPBgNVBAgTCElsbGlub2lzMRMwEQYDVQQHEwpSaXZlcndvb2RzMSQwIgYDVQQK
                ExtEaXNjb3ZlciBGaW5hbmNpYWwgU2VydmljZXMxGTAXBgNVBAsTEFBheW1lbnQg
                U2VydmljZXMxJDAiBgNVBAMTG2V4dGVudGVkcm9vdC5wcm90ZWN0YnV5LmNvbTCC
                ASAwDQYJKoZIhvcNAQEBBQADggENADCCAQgCggEBALNsyG9oPkqHwiJ0MeXTkeHO
                +HB7Nktvac0tjRY3ieiloPI90mVaS2etV2yLJw3R7qHq5HjNK5Zr+eg63T6zZwh/
                EIxivpR2qwOVv/+ckTuycKfHGgsteKkC/NQEaIXly4voQUhRdkr3bemBBQR9G2Pa
                +zxuPE5PgC5jnBqabE07exgBemRQpaSlwDCoEZ7w6zcS64HnvA6VqLyPt/spbvHS
                6kVjjEjDUFoRRq8teFaKoAzkQYp3DyIRmj70UW8EPVsHK1psKIqoblKDsfwZ4xR8
                E6bMsE/tW7LrnGWFrRxzUzZz3y0BaZbGb/lzdbcxu/ZczQx+176HO4t3f6ZMJiEC
                AQOjgewwgekwIgYDVR0jAQEABBgwFoAUzRpCPovmFP5lf7UtRZ3jArTB/wcwIAYD
                VR0OAQEABBYEFM0aQj6L5hT+ZX+1LUWd4wK0wf8HMBIGA1UdEwEB/wQIMAYBAf8C
                AQEwDwYDVR0PAQH/BAUDAwCGADAqBgNVHSUBAQAEIDAeBggrBgEFBQcDAQYIKwYB
                BQUHAwIGCCsGAQUFBwMJMFAGA1UdHwEBAARGMEQwQqJAhj5odHRwOi8vd3d3LmRp
                c2NvdmVyZmluYW5jaWFsY2VydC5jb20vY3Jscy9SZXZvY2F0aW9uTGlzdF8xLmNy
                bDANBgkqhkiG9w0BAQUFAAOCAQEAWEQpwrxMRthv6LbAeLL5jE5C7li1P9KxNTWS
                5NY+JlC1PmEIsqdWOdweXTyfIQ7rWuKJjEy1EZY7t/WKJYEk/mLS4Gr0RdP2wkus
                tKWaoFjWKp0xcRotKoB8ybGY53KwqDpsTZHZBKNTcpPLdcqX+XWSEHNqkyNizKcF
                xH/wJodPhQLzHnPAOBIl34IaOx8r98/bAoTC/XQ87tnh8PK+ZgHyr9igvhuL/L3v
                EJT4iUu5AwGTFDtFRls03Le1BK2aVwf1e+tWatlbQhqxBuj9w8k0BoR/+eM9vdPI
                I7PvKE8UlqzD4CulHpFaKnltBPkZllf9TDI+Nmwx4JQ2kKBpOg==
                -----END CERTIFICATE-----
                """
                
        case .visa:
            return """
                -----BEGIN CERTIFICATE-----
                MIIDojCCAoqgAwIBAgIQE4Y1TR0/BvLB+WUF1ZAcYjANBgkqhkiG9w0BAQUFADBr
                MQswCQYDVQQGEwJVUzENMAsGA1UEChMEVklTQTEvMC0GA1UECxMmVmlzYSBJbnRl
                cm5hdGlvbmFsIFNlcnZpY2UgQXNzb2NpYXRpb24xHDAaBgNVBAMTE1Zpc2EgZUNv
                bW1lcmNlIFJvb3QwHhcNMDIwNjI2MDIxODM2WhcNMjIwNjI0MDAxNjEyWjBrMQsw
                CQYDVQQGEwJVUzENMAsGA1UEChMEVklTQTEvMC0GA1UECxMmVmlzYSBJbnRlcm5h
                dGlvbmFsIFNlcnZpY2UgQXNzb2NpYXRpb24xHDAaBgNVBAMTE1Zpc2EgZUNvbW1l
                cmNlIFJvb3QwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCvV95WHm6h
                2mCxlCfLF9sHP4CFT8icttD0b0/Pmdjh28JIXDqsOTPHH2qLJj0rNfVIsZHBAk4E
                lpF7sDPwsRROEW+1QK8bRaVK7362rPKgH1g/EkZgPI2h4H3PVz4zHvtH8aoVlwdV
                ZqW1LS7YgFmypw23RuwhY/81q6UCzyr0TP579ZRdhE2o8mCP2w4lPJ9zcc+U30rq
                299yOIzzlr3xF7zSujtFWsan9sYXiwGd/BmoKoMWuDpI/k4+oKsGGelT84ATB+0t
                vz8KPFUgOSwsAGl0lUq8ILKpeeUYiZGo3BxN77t+Nwtd/jmliFKMAGzsGHxBvfaL
                dXe6YJ2E5/4tAgMBAAGjQjBAMA8GA1UdEwEB/wQFMAMBAf8wDgYDVR0PAQH/BAQD
                AgEGMB0GA1UdDgQWBBQVOIMPPyw/cDMezUb+B4wg4NfDtzANBgkqhkiG9w0BAQUF
                AAOCAQEAX/FBfXxcCLkr4NWSR/pnXKUTwwMhmytMiUbPWU3J/qVAtmPN3XEolWcR
                zCSs00Rsca4BIGsDoo8Ytyk6feUWYFN4PMCvFYP3j1IzJL1kk5fui/fbGKhtcbP3
                LBfQdCVp9/5rPJS+TUtBjE7ic9DjkCJzQ83z7+pzzkWKsKZJ/0x9nXGIxHYdkFsd
                7v3M9+79YKWxehZx0RbQfBI8bGmX265fOZpwLwU8GUYEmSA20GBuYQa7FkKMcPcw
                ++DbZqMAAb3mLNqRX6BGi01qnD093QVG/na/oAo85ADmJ7f/hC3euiInlhBx6yLt
                398znM/jra6O1I7mT1GvFpLgXPYHDw==
                -----END CERTIFICATE-----
                """
                
        case .mastercard:
            return """
                -----BEGIN CERTIFICATE-----
                MIIFxzCCA6+gAwIBAgIQFsjyIuqhw80wNMjXU47lfjANBgkqhkiG9w0BAQsFADB8
                MQswCQYDVQQGEwJVUzETMBEGA1UEChMKTWFzdGVyQ2FyZDEoMCYGA1UECxMfTWFz
                dGVyQ2FyZCBJZGVudGl0eSBDaGVjayBHZW4gMzEuMCwGA1UEAxMlUFJEIE1hc3Rl
                ckNhcmQgSWRlbnRpdHkgQ2hlY2sgUm9vdCBDQTAeFw0xNjA3MTQwNzI0MDBaFw0z
                MDA3MTUwODEwMDBaMHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQKEwpNYXN0ZXJDYXJk
                MSgwJgYDVQQLEx9NYXN0ZXJDYXJkIElkZW50aXR5IENoZWNrIEdlbiAzMS4wLAYD
                VQQDEyVQUkQgTWFzdGVyQ2FyZCBJZGVudGl0eSBDaGVjayBSb290IENBMIICIjAN
                BgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAxZF3nCEiT8XFFaq+3BPT0cMDlWE7
                6IBsdx27w3hLxwVLog42UTasIgzmysTKpBc17HEZyNAqk9GrCHo0Oyk4JZuXHoW8
                0goZaR2sMnn49ytt7aGsE1PsfVup8gqAorfm3IFab2/CniJJNXaWPgn94+U/nsoa
                qTQ6j+6JBoIwnFklhbXHfKrqlkUZJCYaWbZRiQ7nkANYYM2Td3N87FmRanmDXj5B
                G6lc9o1clTC7UvRQmNIL9OdDDZ8qlqY2Fi0eztBnuo2DUS5tGdVy8SgqPM3E12ft
                k4EdlKyrWmBqFcYwGx4AcSJ88O3rQmRBMxtk0r5vhgr6hDCGq7FHK/hQFP9LhUO9
                1qxWEtMn76Sa7DPCLas+tfNRVwG12FBuEZFhdS/qKMdIYUE5Q6uwGTEvTzg2kmgJ
                T3sNa6dbhlYnYn9iIjTh0dPGgiXap1Bhi8B9aaPFcHEHSqW8nZUINcrwf5AUi+7D
                +q/AG5ItiBtQTCaaFm74gv51yutzwgKnH9Q+x3mtuK/uwlLCslj9DeXgOzMWFxFg
                uuwLGX39ktDnetxNw3PLabjHkDlGDIfx0MCQakM74sTcuW8ICiHvNA7fxXCnbtjs
                y7at/yXYwAd+IDS51MA/g3OYVN4M+0pG843Re6Z53oODp0Ymugx0FNO1NxT3HO1h
                d7dXyjAV/tN/GGcCAwEAAaNFMEMwDgYDVR0PAQH/BAQDAgGGMBIGA1UdEwEB/wQI
                MAYBAf8CAQEwHQYDVR0OBBYEFNSlUaqS2hGLFMT/EXrhHeEx+UqxMA0GCSqGSIb3
                DQEBCwUAA4ICAQBLqIYorrtVz56F6WOoLX9CcRjSFim7gO873a3p7+62I6joXMsM
                r0nd9nRPcEwduEloZXwFgErVUQWaUZWNpue0mGvU7BUAgV9Tu0J0yA+9srizVoMv
                x+o4zTJ3Vu5p5aTf1aYoH1xYVo5ooFgl/hI/EXD2lo/xOUfPKXBY7twfiqOziQmT
                GBuqPRq8h3dQRlXYxX/rzGf80SecIT6wo9KavDkjOmJWGzzHsn6Ryo6MEClMaPn0
                te87ukNN740AdPhTvNeZdWlwyqWAJpsv24caEckjSpgpoIZOjc7PAcEVQOWFSxUe
                sMk4Jz5bVZa/ABjzcp+rsq1QLSJ5quqHwWFTewChwpw5gpw+E5SpKY6FIHPlTdl+
                qHThvN8lsKNAQg0qTdEbIFZCUQC0Cl3Ti3q/cXv8tguLJNWvdGzB600Y32QHclMp
                eyabT4/QeOesqpx6Da70J2KvLT1j6Ch2BsKSzeVLahrjnoPrdgiIYYBOgeA3T8SE
                1pgagt56R7nIkRQbtesoRKi+NfC7pPb/G1VUsj/cREAHH1i1UKa0aCsIiANfEdQN
                5Ok6wtFJJhp3apAvnVkrZDfOG5we9bYzvGoI7SUnleURBJ+N3ihjARfL4hDeeRHh
                YyLkM3kEyEkrJBL5r0GDjicxM+aFcR2fCBAkv3grT5kz4kLcvsmHX+9DBw==
                -----END CERTIFICATE-----
                """
        case .amex:
            return """
                -----BEGIN CERTIFICATE-----
                MIIDpjCCAo6gAwIBAgIUKIUEno8uwk6ousVAaZDnEVRYgTAwDQYJKoZIhvcNAQEL
                BQAwazELMAkGA1UEBhMCVVMxITAfBgNVBAoTGEFtZXJpY2FuIEV4cHJlc3MgQ29t
                cGFueTE5MDcGA1UEAxMwQW1lcmljYW4gRXhwcmVzcyBQcml2YXRlIENlcnRpZmlj
                YXRpb24gQXV0aG9yaXR5MB4XDTE0MDgxMTE0NTMwN1oXDTI5MDgxMTE0NTMwN1ow
                azELMAkGA1UEBhMCVVMxITAfBgNVBAoTGEFtZXJpY2FuIEV4cHJlc3MgQ29tcGFu
                eTE5MDcGA1UEAxMwQW1lcmljYW4gRXhwcmVzcyBQcml2YXRlIENlcnRpZmljYXRp
                b24gQXV0aG9yaXR5MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAvEEf
                8v/HaYba4PeyMcoHP4yRpRi7GcVVkQlHltb40/KuR1/dzAtvS3gxVO0COetO1zsf
                pAvfyJ8MJl2HA++264XqUZ8y/OUjyup0Wu9BPKgeRn2D7AOFa3ybY4tXvJjUom40
                A4G/VZWpKHKzn+ltLs2POYyN9MDPPHb8GJnVtNBKecUdJH4RR9vunVRyxqqjYnPX
                /WfYdrEIkV8bZb5D0tnFXJYXAqnSlYmY2SJs2rVWfvpsIfwvAQvfa0zYTs32FsjA
                mySN7GNSWyTAoSBfGxiXcR29Dm0jgveAvwiK46z/tNVD/uLARf4P3JcgkDcCIBQ/
                WAfAdqlhqF/AY4bjiwIDAQABo0IwQDAPBgNVHRMBAf8EBTADAQH/MA4GA1UdDwEB
                /wQEAwIBxjAdBgNVHQ4EFgQUpeoTDAJApCDbS1ox5CT6mqtJ+2owDQYJKoZIhvcN
                AQELBQADggEBAE1GH7WI23sLPHAPW/Ye9TIsg1zEyOzogVdWWD5z45kPzzNzJv/7
                IDfYpIfwwf1K7dKTvkTr91bEear+vsgAXabKDppaXjOqxQIV4q9whoZzy0xcu3wA
                D80slzlAMyUqmKqI5JRHkq900nYw5VF27m2gevefQRoo24BtSC5uBgKq5NS9+vnY
                kT/USgt0/bhc0zW9ytckI/E5oO0cu3l2yDJBHmsbg7OLpKTnVacBSiR25gk3fzCo
                ucdkKEMnocZ8YTKU623oEs440NYYmGhRh6S0RBqREHELPzoKpxZa20FLRpbWdTCp
                iSuhpMJJkPctEBxB6Osop+M+ZwSlGrl+o14=
                -----END CERTIFICATE-----
                """
            
        case .jcb:
            return """
            -----BEGIN CERTIFICATE-----
            MIIDVzCCAj+gAwIBAgIBATANBgkqhkiG9w0BAQsFADBNMQswCQYDVQQGEwJKUDEW
            MBQGA1UEChMNSkNCIENvLiwgTHRkLjEmMCQGA1UEAxMdSkNCIERTIFJvb3QgQ0Eg
            RU1WIDMtRCBTZWN1cmUwHhcNMTgwMTA5MDIzOTMzWhcNMzYwMTA5MDIzOTMzWjBN
            MQswCQYDVQQGEwJKUDEWMBQGA1UEChMNSkNCIENvLiwgTHRkLjEmMCQGA1UEAxMd
            SkNCIERTIFJvb3QgQ0EgRU1WIDMtRCBTZWN1cmUwggEiMA0GCSqGSIb3DQEBAQUA
            A4IBDwAwggEKAoIBAQCmSll0tye7bZoLVu+fEMczcGKHmEVv6hFcDSjjiyl+O2yH
            l+uwtJQ3liRLb/c88a12OOtvitC8jPb2mRJu4F2RBjh+/k+DRuHO/FNRHp44aCF3
            L4gDKU456rHKr3Ue3WJnGum9Xb/X5POp5hNf0/KZIojtSbgmFLkzEaL+gFxuNPlC
            WSHa0P4wmZP97IAHh6qfGt15Al11qarpqwCjLSKsv9IxTCC80n6da5AWgb59k6pP
            dLRmVCWiz+zXziWSzQN6DHLGJpPWVN+Wk33Z05dS6AZa7VifMg31lCdFCt9FuPFx
            AJ++nWydNOQp/Pw31U47IOsrg97Ung6mytMWzjWRAgMBAAGjQjBAMA8GA1UdEwEB
            /wQFMAMBAf8wDgYDVR0PAQH/BAQDAgHGMB0GA1UdDgQWBBTu+hXcLdA0GBsvzGca
            RnEKVakh3jANBgkqhkiG9w0BAQsFAAOCAQEAcUt8ELxW/wQwxDTKZFYF5slFrcjb
            WIeqpcb9rolrqsCmiFsT6IjdsvV+GA4c9WRCoqeFVE+BPiQytc4zuyxBKS8sipMn
            FyB23YkOTViP5WRv3QDCDcfYalPRJpt8TSrqS2Bw4khtVOc4qRlA5PgRtvKgRVKo
            zBAbzPOAHCZB+IcuRL4c5ioI/rp6bJTXupdevgVHoNdGpkSNcW7iaXq1r31dBop1
            8efVyY1jeQn+sYjSXBVNKKQCyfEXo5JXQTaWDVCPtX5p2M5tnQA5szv8gWkzpkqN
            O+1PGSIyLBJnl29N3wCTyIuRrVe6IHdRtb0ongrGA+tAUeU5sZXRR43gag==
            -----END CERTIFICATE-----
            """
                
        case .msigniaRSA, .msigniaEC, .demoMC, .demoVisa, .demoDiscover, .demoAmex, .demoCB, .demoJCB:
            return """
                -----BEGIN CERTIFICATE-----
                MIID4zCCAsugAwIBAgIBATANBgkqhkiG9w0BAQsFADB7MQswCQYDVQQGEwJVUzEL
                MAkGA1UECBMCVE4xEDAOBgNVBAoTB01TSUdOSUExDDAKBgNVBAsTA1JORDEXMBUG
                A1UEAxMOTVNJR05JQSBSTkQgQ0ExJjAkBgkqhkiG9w0BCQEWF3BhdmxvLmx5c292
                QG1zaWduaWEuY29tMB4XDTE5MTExMzA3MzYwMFoXDTI5MTExMzA3MzYwMFowezEL
                MAkGA1UEBhMCVVMxCzAJBgNVBAgTAlROMRAwDgYDVQQKEwdNU0lHTklBMQwwCgYD
                VQQLEwNSTkQxFzAVBgNVBAMTDk1TSUdOSUEgUk5EIENBMSYwJAYJKoZIhvcNAQkB
                FhdwYXZsby5seXNvdkBtc2lnbmlhLmNvbTCCASIwDQYJKoZIhvcNAQEBBQADggEP
                ADCCAQoCggEBAPSn+PdwUVXYq5IQN+vrcxM3WfR5Xpgb3OpIRkka863duH0j3Uh/
                poaFxnp/j0dGbefYaKaXGZSFX/E3FWaAFGKHV2Lbt4uxYkJx4Fa2gXsBxqdOd4Li
                aqSRSZXPtYMqoMbCOQj4lqtthBNe5BDX6/1HDJELLo8sxnIyfwxgbome3s9e6Rpz
                p+M9XgOtfyuSzPhzY0bWeBrHDzPcKkxQgKZeywlgApCPPfoYEvBDfzGbNns4yA+v
                sqYGDcctplQceUG6EFN68qbmy3CzV8zQMHFkHqIJ/l1V5RlGT9b5QhNVhu4MJo//
                W8LaA6vdyyqPnS7Hbvp6JklkMVxJJhWl0t8CAwEAAaNyMHAwDwYDVR0TAQH/BAUw
                AwEB/zAdBgNVHQ4EFgQU443mM7cesLlNiq01jfVfyJ7Rh1gwCwYDVR0PBAQDAgEG
                MBEGCWCGSAGG+EIBAQQEAwIABzAeBglghkgBhvhCAQ0EERYPeGNhIGNlcnRpZmlj
                YXRlMA0GCSqGSIb3DQEBCwUAA4IBAQBOY7ETJ0MyrQ44MYNbkGI7fIij5oxM0In0
                Z4ZT5NCA1p3fJP/PV8oxONE+7ix1GlCw8RR59L2VQGkg4I2vSj0DHqpuPf3u86Fm
                gZtkhcF41dlWSic1B5oaA610iglITgu/gyZrC+r6RHGIKfyLX+u8YGc6WfI8g/ED
                aVQcnq/PZAEeZtBGiZdYxnIQhIOxV04nFmtOjSyyMt5NXMHFLHRnewSI6tojcFm2
                lm6WMZQXFqGyvkxjmPQXFFBCupAAPIkm0lIIvZqtvLOOqmU7et4Oy5pihyaHjg67
                cdmlv/p990e7YYfzdQSKezWrdwXW4EAGBTyuAZ67a5XCOUi17JZU
                -----END CERTIFICATE-----
                """
        }
    }
    
    // MARK: - Inits
    init(id: String) {
        switch id {
        case DirectoryServerInfo.discover.rawValue:
            self = .discover
            
        case DirectoryServerInfo.visa.rawValue:
            self = .visa
            
        case DirectoryServerInfo.mastercard.rawValue:
            self = .mastercard
            
        case DirectoryServerInfo.amex.rawValue:
            self = .amex
            
        case DirectoryServerInfo.msigniaEC.rawValue:
            self = .msigniaEC
            
        case DirectoryServerInfo.msigniaRSA.rawValue:
            self = .msigniaRSA
            
        case DirectoryServerInfo.jcb.rawValue:
            self = .jcb
            
        case DirectoryServerInfo.demoMC.rawValue:
            self = .demoMC
            
        case DirectoryServerInfo.demoVisa.rawValue:
            self = .demoVisa
            
        case DirectoryServerInfo.demoDiscover.rawValue:
            self = .demoDiscover
            
        case DirectoryServerInfo.demoAmex.rawValue:
            self = .demoAmex
            
        case DirectoryServerInfo.demoCB.rawValue:
            self = .demoCB
            
        case DirectoryServerInfo.demoJCB.rawValue:
            self = .demoJCB
            
        default:
            self = .msigniaRSA
        }
    }
}
