//
//  AuthenticationRequestParameters.swift
//  ThreeDS-Sample
//
//  Created by Drew Pitchford on 3/29/21.
//  Copyright © 2021 mSignia. All rights reserved.
//

import Foundation
import AnyCodable

class AuthenticationRequestParameters: Codable {
    
    // MARK: - Properties
    var messageVersion: String
    var messageCategory: String
    var dsIdentifier: String
    var deviceData: String
    var sdkTransactionID: String
    var sdkAppID: String
    var sdkReferenceNumber: String
    var sdkType: String
    var supportedVersionsThreeDSServerTransID: String
    var extraAuthParams: AnyCodable?
    var deviceChannel = "01"
    var sdkMaxTimeout = "10"
    var deviceRenderOptions: DeviceRenderOptions
    var sdkEphemeralPublicKey: SDKEphemPubKey?
    
    // MARK: - Inits
    init(messageVersion: String, messageCategory: String, dsIdentifier: String, deviceData: String, sdkTransactionID: String, sdkAppID: String, sdkReferenceNumber: String, sdkType: String, supportedVersionsThreeDSServerTransID: String, extraAuthParams: AnyCodable? = nil, sdkEphemPubKey: String) {
        self.messageVersion = messageVersion
        self.messageCategory = messageCategory
        self.dsIdentifier = dsIdentifier
        self.deviceData = deviceData
        self.sdkTransactionID = sdkTransactionID
        self.sdkAppID = sdkAppID
        self.sdkReferenceNumber = sdkReferenceNumber
        self.sdkType = sdkType
        self.supportedVersionsThreeDSServerTransID = supportedVersionsThreeDSServerTransID
        self.extraAuthParams = extraAuthParams
        
        if messageVersion == "2.3.0" {
            deviceRenderOptions = DeviceRenderOptions(sdkAuthenticationType: ["01", "02", "03", "04", "05", "06", "07" , "08", "09", "10", "11"])
        }
        else {
            deviceRenderOptions = DeviceRenderOptions()
        }
        
        if let data = sdkEphemPubKey.data(using: .utf8),
           let decodedKey = JsonUtil.decode(SDKEphemPubKey.self, from: data).response {
            sdkEphemeralPublicKey = decodedKey
        }
    }
}

class SDKEphemPubKey: Codable {
    
    // MARK: - Properties
    var crv: String
    var kty: String
    var y: String
    var x: String
    
    // MARK: - Init
    init(crv: String, kty: String, y: String, x: String) {
        self.crv = crv
        self.kty = kty
        self.y = y
        self.x = x
    }
}

class DeviceRenderOptions: Codable {
    
    // MARK: - Properties
    var sdkInterface = "03"
    var sdkUiType = ["01", "02", "03", "04", "05"]
    var sdkAuthenticationType: [String]?
    
    // MARK: - Init
    init(sdkAuthenticationType: [String]? = nil) {
        self.sdkAuthenticationType = sdkAuthenticationType
    }
}
