//
//  AuthenticationResponse.swift
//  ThreeDS-Sample
//
//  Created by Drew Pitchford on 3/29/21.
//  Copyright © 2021 mSignia. All rights reserved.
//

import Foundation
import uSDK

enum TransactionStatus: String, Codable {
    
    // MARK: - Cases
    case accept = "Y"
    case deny = "N"
    case challenge = "C"
    case attempted = "A"
    case notPerformed = "U"
    case decoupledAuthentication = "D"
    case informationOnly = "I"
    case rejected = "R"
    
    // MARK: - UTransStatusConverter
    static func convert(from uTransStatus: UTransStatus) -> TransactionStatus {
        switch uTransStatus {
        case .accept:
            return .accept
        case .attempted:
            return .attempted
        case .challenge:
            return .challenge
        case .decoupledAuthentication:
            return .decoupledAuthentication
        case .deny:
            return .deny
        case .informationOnly:
            return .informationOnly
        case .notPerformed:
            return .notPerformed
        case .rejected:
            return .rejected
        default:
            return .accept
        }
    }
}

class AuthenticationResponse: Codable {
    
    // MARK: - Properties
    var acsTransID: String?
    var dsTransID: String?
    var eci: String?
    var threeDSServerTransID: String?
    var messageVersion: String?
    var acsChallengeMandated: String?
    var transStatus: TransactionStatus?
    var acsOperatorID: String?
    var dsReferenceNumber: String?
    var acsReferenceNumber: String?
    var authenticationValue: String?
    var messageType: String?
    var sdkTransID: String?
    var acsSignedContent: String?
    var messageExtension: [MessageExtension]?
    
    // MARK: - Inits
    init(acsTransID: String?, dsTransID: String?, eci: String?, threeDSServerTransID: String?, messageVersion: String?, acsChallengeMandated: String?, transStatus: TransactionStatus?, acsOperatorID: String?, dsReferenceNumber: String?, acsReferenceNumber: String?, authenticationValue: String?, messageType: String?, sdkTransID: String?, acsSignedContent: String?, messageExtension: [MessageExtension]? = nil) {
        
        self.acsTransID = acsTransID
        self.dsTransID = dsTransID
        self.eci = eci
        self.threeDSServerTransID = threeDSServerTransID
        self.messageVersion = messageVersion
        self.acsChallengeMandated = acsChallengeMandated
        self.transStatus = transStatus
        self.acsOperatorID = acsOperatorID
        self.dsReferenceNumber = dsReferenceNumber
        self.acsReferenceNumber = acsReferenceNumber
        self.authenticationValue = authenticationValue
        self.messageType = messageType
        self.sdkTransID = sdkTransID
        self.acsSignedContent = acsSignedContent
        self.messageExtension = messageExtension
    }
}
