//Copyright © mSIGNIA, Incorporated, 2007.  All rights reserved.
//
//Software is protected by one or more of U.S. Patent No. 9,559,852, 9294448, 8,817,984,
//international patents and others pending. For more information see www.mSIGNIA.com.  User agrees
//that they will not them self, or through any affiliate, agent or other third-party, entity or
//other business structure remove, alter, cover or obfuscate any copyright notices or other
//proprietary rights notices of mSIGNIA or its licensors.  User agrees that they will not them
//self, or through any affiliate, agent or other third party, entity or other business structure
//(a) reproduce, sell, lease, license or sublicense this software or any part thereof, (b)
//decompile, disassemble, re-program, reverse engineer or otherwise attempt to derive or modify
//this software in whole or in part, (c) write or develop any derivative software or any other
//software program based upon this software, (d) provide, copy, transmit, disclose, divulge, or
//make available to, or permit use of this software by any third party or entity or machine without
//software owner's prior written consent, (e) circumvent or disable any security or other
//technological features or measures used by this software.
//
//  MessageExtension.swift
//  ThreeDSStoreDemo
//
//  Created by Drew Pitchford on 12/6/18.
//  Copyright © 2018 mSignia. All rights reserved.
//

import Foundation
import uSDK

enum SCAMethod: String, Codable {
    case deviceCookie = "DEVICE_COOKIE"
    case deviceAngle = "DEVICE_ANGLE"
    case merchantPrompt = "MERCHANT_PROMPT"
    case usdkPromptText = "USDK_PROMPT_TEXT"
    case typingPattern = "TYPING_PATTERN"
    case behavioralMetrics = "BEHAVIORAL_METRICS"
    case usdkPromptLocalBioAuth = "USDK_PROMPT_LOCAL_BIO_AUTH"
}

enum USDKKeyboardType: String, Codable {
    case numeric = "NUMERIC"
    case email = "EMAIL"
    case empty = ""
    
    var uiKeyboardType: UIKeyboardType {
        switch self {
        case .numeric:
            return .numberPad
            
        case .email, .empty:
            return .emailAddress
        }
    }
}

class PublicKey: Codable {
    var kty: String
    var crv: String
    var x: String
    var y: String
    
    init(kty: String, crv: String, x: String, y: String) {
        self.kty = kty
        self.crv = crv
        self.x = x
        self.y = y
    }
    
    // MARK: Json
    func toJson() -> [String: Any] {
        var dict: [String: Any] = [:]
        dict["kty"] = kty
        dict["crv"] = crv
        dict["x"] = x
        dict["y"] = y
        
        return dict
    }
}

class USDKPrompt: Codable {
    
    // MARK: - Properties
    var heading: String
    var message: String
    var keyboard: USDKKeyboardType
    
    // MARK: - Inits
    init(heading: String, message: String, keyboard: USDKKeyboardType) {
        self.heading = heading
        self.message = message
        self.keyboard = keyboard
    }
    
    // MARK: - Json
    func toJson() -> [String: Any] {
        var dict: [String: Any] = [:]
        dict["heading"] = heading
        dict["message"] = message
        dict["keyboard"] = keyboard.rawValue
        
        return dict
    }
}

class FIGData: Codable {
    
    // MARK: - Properties
    var deviceCookie: String?
    var acsReferenceNumber: String?
    var methods: [SCAMethod]?
    var acsEphemPubKey: PublicKey?
    var bankId: String?
    var usdkPrompt: USDKPrompt?
    var methodsStrings: [String] {
        var strings: [String] = []
        for method in methods ?? [] {
            strings.append(method.rawValue)
        }
        
        return strings
    }
    
    // MARK: - inits
    init(deviceCookie: String, acsReference: String, methods: [SCAMethod], acsEphemPubKey: PublicKey, bankID: String?, usdkPrompt: USDKPrompt?) {
        self.deviceCookie = deviceCookie
        self.acsReferenceNumber = acsReference
        self.methods = methods
        self.acsEphemPubKey = acsEphemPubKey
        self.bankId = bankID;
        self.usdkPrompt = usdkPrompt
    }
    
    // MARK: - Json
    func toJson() -> [String: Any] {
        var json: [String: Any] = [:]
        if let deviceCookie = deviceCookie {
            json["deviceCookie"] = deviceCookie
        }
        
        if let acsRefNumber = acsReferenceNumber {
            json["acsReferenceNumber"] = acsRefNumber
        }
        
        if let _ = methods {
            json["methods"] = methodsStrings
        }
        
        if let acsEphemPubKey = acsEphemPubKey {
            json["acsEphemPubKey"] = acsEphemPubKey.toJson()
        }
        
        if let bankId = bankId {
            json["bankId"] = bankId
        }
        
        if let usdkPrompt = usdkPrompt {
            json["usdkPrompt"] = usdkPrompt.toJson()
        }
    
        return json
    }
}

class MessageExtension: Codable {
    
    // MARK: - Properties
    var id: String
    var name: String
    var criticalityIndicator: Bool
    var data: FIGData
    
    // MARK: - inits
    init(id: String, name: String, criticalityIndicator: Bool, data: FIGData) {
        
        self.id = id
        self.name = name
        self.criticalityIndicator = criticalityIndicator
        self.data = data
    }
    
    // MARK: - Json
    func toJson() -> [String: Any] {
        var dict: [String: Any] = [:]
        dict["id"] = id
        dict["name"] = name
        dict["criticalityIndicator"] = criticalityIndicator
        dict["data"] = data.toJson()
        
        return dict
    }
}
