//
//  PurchaseRequest.swift
//  ThreeDS-Sample
//
//  Created by Drew Pitchford on 4/9/20.
//  Copyright © 2020 mSignia. All rights reserved.
//

import Foundation
import uSDK

class PurchaseRequest: Codable {
    // MARK: - Properties
    let sdkMaxTimeout = "60"
    let deviceRenderOptions = DeviceRenderOptions()
    let authRequestParameters: DemoAuthRequestParams
    var acctNumber: String
    
    // MARK: - Inits
    init(authRequestParams: DemoAuthRequestParams, acctNumber: String) {
        authRequestParameters = authRequestParams
        self.acctNumber = acctNumber
    }
}

class DemoAuthRequestParams: Codable {
    // MARK: - Properties
    var deviceData: String
    var sdkTransactionID: String
    var sdkAppID: String
    var sdkReferenceNumber: String
    var sdkEphemeralPublicKey: String
    var messageVersion: String
    
    // MARK: - Init
    init(deviceData: String, sdkTransactionID: String, sdkAppID: String, sdkReferenceNumber: String, sdkEphemeralPublicKey: String, messageVersion: String) {
        self.deviceData = deviceData
        self.sdkTransactionID = sdkTransactionID
        self.sdkAppID = sdkAppID
        self.sdkReferenceNumber = sdkReferenceNumber
        self.sdkEphemeralPublicKey = sdkEphemeralPublicKey
        self.messageVersion = messageVersion
    }
    
    init(authRequestParams: UAuthenticationRequestParameters) {
        deviceData = authRequestParams.getDeviceData()
        sdkTransactionID = authRequestParams.getSDKTransactionID()
        sdkAppID = authRequestParams.getSDKAppID()
        sdkReferenceNumber = authRequestParams.getSDKReferenceNumber()
        sdkEphemeralPublicKey = authRequestParams.getSDKEphemeralPublicKey()
        messageVersion = authRequestParams.getMessageVersion()
    }
}

class DeviceRenderOptions: Codable {
    // MARK: - Properties
    let sdkInterface = "03"
    let sdkUiType = ["01", "02", "03", "04", "05"]
}
