//
//  SDKThemeManager.swift
//  emvco3ds-ios-app
//
//  Created by Work Drew on 5/2/18.
//  Copyright © 2018 UL Transaction Security. All rights reserved.
//

import Foundation
import uSDK

struct SDK {
    
    static let standardCornerRadius = 7
    static let standardBorderWidth = 1
    static let softerCornerRadius = 5
    static let standardTextSize = 17
    static let h2TextSize = 18
    static let h1TextSize = 20
    static let standardLabelTextColor = "#000000"
    static let standardButtonTextColor = "#FFFFFF"
    static let standardButtonBackgroundColor = "#007aff"
    static let standardTextBoxTextColor = "#000000"
    static let standardTextBoxBorderColor = "#007aff"
    static let standardToolbarBackgroundColor = "#FFFFFF"
    static let standardToolbarTextColor = "#000000"
    static let standardToolbarButtonText = "Cancel"
    static let standardToolBarText = "3DS Sample App"
    static let standardFontName = "AvenirNext-Medium"
    static let h2FontName = "AvenirNext-DemiBold"
    static let h1FontName = "AvenirNext-Bold"
}

class SDKThemeManager {
    
    typealias sdkUI = SDK
    
    // MARK: Singleton
    static let shared = SDKThemeManager()
    
    // MARK: - Properties
    var customization = UUiCustomization(with: ULabelCustomization(), textBoxCustomization: UTextBoxCustomization(), toolbarCustomization: UToolbarCustomization())
    private var labelCustomization = ULabelCustomization()
    private var textBoxCustomization = UTextBoxCustomization()
    private var toolBarCustomization = UToolbarCustomization()
    
    // MARK: - Default Theme
    func setDefaultTheme() {
        
        // Buttons
        try? SDKThemeManager.shared.setButtonCustomization(for: [.submit, .next, .continue])
        
        try? SDKThemeManager.shared.setButtonCustomization(backgroundColor: "#ff3b30", for: [.resend])
        
        try? SDKThemeManager.shared.setButtonCustomization(cornerRadius: SDK.softerCornerRadius, for: [.cancel])
        
        // Labels
        try? SDKThemeManager.shared.setLabelCustomization()
        
        // TextFields
        try? SDKThemeManager.shared.setTextBoxCustomization()
        
        // "Toolbar"
        try? SDKThemeManager.shared.setToolbarCustomization()
    }
    
    // MARK: - Customizable Methods
    func setLabelCustomization(withTextFontName textFontName: String = sdkUI.standardFontName, textColor: String = sdkUI.standardLabelTextColor, textFontSize: Int = sdkUI.standardTextSize, headingTextColor: String = sdkUI.standardLabelTextColor, headingTextFontName: String = sdkUI.h1FontName, headingTextFontSize: Int = sdkUI.h1TextSize) throws {
        
        do {
            
            try labelCustomization.u_setTextFontName(textFontName)
            try labelCustomization.u_setTextColor(textColor)
            try labelCustomization.u_setTextFontSize(textFontSize)
            try labelCustomization.u_setHeadingTextColor(headingTextColor)
            try labelCustomization.u_setHeadingTextFontName(headingTextFontName)
            try labelCustomization.u_setHeadingTextFontSize(headingTextFontSize)
        }
        catch {
            
            print("Error:\(error)")
            throw error
        }
        
        customization.setLabel(labelCustomization)
    }
    
    func setButtonCustomization(withTextColor textColor: String = sdkUI.standardButtonTextColor, textFontName: String = sdkUI.h2FontName, textFontSize: Int = sdkUI.h2TextSize, cornerRadius: Int = sdkUI.standardCornerRadius, backgroundColor: String = sdkUI.standardButtonBackgroundColor, for buttonTypes: [UButtonType]) throws {
        
        for type in buttonTypes {
            
            let result = UButtonCustomization()
            do {
                
                try result.u_setTextColor(textColor)
                try result.u_setTextFontName(textFontName)
                try result.u_setTextFontSize(textFontSize)
                try result.u_setCornerRadius(cornerRadius)
                try result.u_setBackgroundColor(backgroundColor)
            }
            catch {
                
                print("Error: \(error)")
                throw error
            }
            
            customization.setButton(result, with: type)
        }
    }
    
    func setTextBoxCustomization(withTextColor textColor: String = sdkUI.standardTextBoxTextColor, borderColor: String = sdkUI.standardTextBoxBorderColor, textFontSize: Int = sdkUI.standardTextSize, textFontName: String = sdkUI.standardFontName, cornerRadius: Int = sdkUI.standardCornerRadius, borderWidth: Int = sdkUI.standardBorderWidth) throws {
        
        do {
            
            try textBoxCustomization.u_setTextColor(textColor)
            try textBoxCustomization.u_setBorderColor(borderColor)
            try textBoxCustomization.u_setTextFontSize(textFontSize)
            try textBoxCustomization.u_setTextFontName(textFontName)
            try textBoxCustomization.u_setCornerRadius(cornerRadius)
            try textBoxCustomization.u_setBorderWidth(borderWidth)
        }
        catch {
            
            print("Error: \(error)")
            throw error
        }
        
        customization.setTextBox(textBoxCustomization)
    }
    
    func setToolbarCustomization(withBackgroundColor backgroundColor: String = sdkUI.standardToolbarBackgroundColor, fontName: String = sdkUI.h1FontName, textSize: Int = sdkUI.h1TextSize, textColor: String = sdkUI.standardToolbarTextColor, headerText: String = sdkUI.standardToolBarText, buttonText: String = sdkUI.standardToolbarButtonText) throws {
        
        do {
            
            try toolBarCustomization.u_setBackgroundColor(backgroundColor)
            try toolBarCustomization.u_setTextFontName(fontName)
            try toolBarCustomization.u_setTextFontSize(textSize)
            try toolBarCustomization.u_setTextColor(textColor)
            try toolBarCustomization.u_setHeaderText(headerText)
            try toolBarCustomization.u_setButtonText(buttonText)
        }
        catch {
            
            print("Toolbar save Error: \(error)")
            throw error
        }
        
        customization.setToolbar(toolBarCustomization)
    }
}
