//
//  USDKUtil.swift
//  ThreeDS-Sample
//
//  Created by Drew Pitchford on 6/30/21.
//  Copyright © 2021 mSignia. All rights reserved.
//

import Foundation
import UIKit
import uSDK

class USDKUtil {
    
    // MARK: - Actions
    static func initSDK(viewController: UIViewController, configParams: UConfigParameters) {
        guard let licenseKey = BuildEnvironment.licenseKey else {
            viewController.showAlert(message: "Cannot init uSDK with an empty license key")
            return
        }
        
        SDKThemeManager.shared.setDefaultTheme()
        let customization = SDKThemeManager.shared.customization
        let initSpec = UInitSpec(licenseKey: licenseKey, locale: "us", uiCustomization: customization, configParameters: configParams)
        UThreeDS2ServiceImpl.shared().initialize(spec: initSpec) { (error) in
            DispatchQueue.main.async {
                if let err = error {
                    viewController.showAlert(for: err)
                }
                else {
                    print("Warnings provided by the SDK: \(UThreeDS2ServiceImpl.shared().getWarnings() ?? [])")
                }
            }
        }
    }
    
    static func uDirectoryServers() -> [UDirectoryServer] {
        let visa = UDirectoryServer(dsid: DirectoryServerInfo.visa.rawValue, publicKey: DirectoryServerInfo.visa.publicKey, keyID: DirectoryServerInfo.visa.keyID, dsCACertificate: DirectoryServerInfo.visa.caCert, providerName: "Visa", dsLogo: Asset.visa.image)
        let discover = UDirectoryServer(dsid: DirectoryServerInfo.discover.rawValue, publicKey: DirectoryServerInfo.discover.publicKey, keyID: DirectoryServerInfo.discover.keyID, dsCACertificate: DirectoryServerInfo.discover.caCert, providerName: "Discover", dsLogo: Asset.discover.image)
        let amex = UDirectoryServer(dsid: DirectoryServerInfo.amex.rawValue, publicKey: DirectoryServerInfo.amex.publicKey, keyID: DirectoryServerInfo.amex.keyID, dsCACertificate: DirectoryServerInfo.amex.caCert, providerName: "Amex", dsLogo: Asset.amex.image)
        let mc = UDirectoryServer(dsid: DirectoryServerInfo.mastercard.rawValue, publicKey: DirectoryServerInfo.mastercard.publicKey, keyID: DirectoryServerInfo.mastercard.keyID, dsCACertificate: DirectoryServerInfo.mastercard.caCert, providerName: "Mastercard", dsLogo: Asset.mastercard.image)
        let msigniaRSA = UDirectoryServer(dsid: DirectoryServerInfo.msigniaRSA.rawValue, publicKey: DirectoryServerInfo.msigniaRSA.publicKey, keyID: DirectoryServerInfo.msigniaRSA.keyID, dsCACertificate: DirectoryServerInfo.msigniaRSA.caCert, providerName: "Msignia RSA", dsLogo: Asset.mastercard.image)
        let msigniaEC = UDirectoryServer(dsid: DirectoryServerInfo.msigniaEC.rawValue, publicKey: DirectoryServerInfo.msigniaEC.publicKey, keyID: DirectoryServerInfo.msigniaEC.keyID, dsCACertificate: DirectoryServerInfo.msigniaEC.caCert, providerName: "Msignia EC", dsLogo: Asset.cbCard.image)
        
        // MC
        let sandbox = UDirectoryServer(dsid: "SANDBOX_DS", publicKey: DirectoryServerInfo.msigniaEC.publicKey, keyID: DirectoryServerInfo.msigniaEC.keyID, dsCACertificate: DirectoryServerInfo.msigniaEC.caCert, providerName: "Carte Bancaire", dsLogo: Asset.cbCard.image)
        let sandbox2 = UDirectoryServer(dsid: "SANDBOX2", publicKey: DirectoryServerInfo.msigniaRSA.publicKey, keyID: DirectoryServerInfo.msigniaRSA.keyID, dsCACertificate: DirectoryServerInfo.msigniaRSA.caCert, providerName: "Mastercard", dsLogo: Asset.mastercard.image)
        let mcMastercard = UDirectoryServer(dsid: DirectoryServerInfo.mastercard.rawValue, publicKey: DirectoryServerInfo.mastercard.publicKey, keyID: DirectoryServerInfo.mastercard.keyID, dsCACertificate: DirectoryServerInfo.mastercard.caCert, providerName: "Mastercard", dsLogo: Asset.mastercard.image)
        let mcVisa = UDirectoryServer(dsid: DirectoryServerInfo.visa.rawValue, publicKey: DirectoryServerInfo.visa.publicKey, keyID: DirectoryServerInfo.visa.keyID, dsCACertificate: DirectoryServerInfo.visa.caCert, providerName: "Visa", dsLogo: Asset.visa.image)
        let mcAmex = UDirectoryServer(dsid: DirectoryServerInfo.amex.rawValue, publicKey: DirectoryServerInfo.amex.publicKey, keyID: DirectoryServerInfo.amex.keyID, dsCACertificate: DirectoryServerInfo.amex.caCert, providerName: "Amex", dsLogo: Asset.amex.image)
        let mcDiscover = UDirectoryServer(dsid: DirectoryServerInfo.discover.rawValue, publicKey: DirectoryServerInfo.discover.publicKey, keyID: DirectoryServerInfo.discover.keyID, dsCACertificate: DirectoryServerInfo.discover.caCert, providerName: "Discover", dsLogo: Asset.discover.image)
        
        // Demo Only
        let demoMC = UDirectoryServer(dsid: DirectoryServerInfo.demoMC.rawValue, publicKey: DirectoryServerInfo.msigniaRSA.publicKey, keyID: DirectoryServerInfo.msigniaRSA.keyID, dsCACertificate: DirectoryServerInfo.msigniaRSA.caCert, providerName: "Mastercard", dsLogo: Asset.mastercard.image)
        let demoVisa = UDirectoryServer(dsid: DirectoryServerInfo.demoVisa.rawValue, publicKey: DirectoryServerInfo.msigniaRSA.publicKey, keyID: DirectoryServerInfo.msigniaRSA.keyID, dsCACertificate: DirectoryServerInfo.msigniaRSA.caCert, providerName: "Visa", dsLogo: Asset.visa.image)
        let demoDiscover = UDirectoryServer(dsid: DirectoryServerInfo.demoDiscover.rawValue, publicKey: DirectoryServerInfo.msigniaRSA.publicKey, keyID: DirectoryServerInfo.msigniaRSA.keyID, dsCACertificate: DirectoryServerInfo.msigniaRSA.caCert, providerName: "Discover", dsLogo: Asset.discover.image)
        let demoAmex = UDirectoryServer(dsid: DirectoryServerInfo.demoAmex.rawValue, publicKey: DirectoryServerInfo.msigniaRSA.publicKey, keyID: DirectoryServerInfo.msigniaRSA.keyID, dsCACertificate: DirectoryServerInfo.msigniaRSA.caCert, providerName: "Amex", dsLogo: Asset.amex.image)
        let demoCB = UDirectoryServer(dsid: DirectoryServerInfo.demoCB.rawValue, publicKey: DirectoryServerInfo.msigniaRSA.publicKey, keyID: DirectoryServerInfo.msigniaRSA.keyID, dsCACertificate: DirectoryServerInfo.msigniaRSA.caCert, providerName: "CB", dsLogo: Asset.cbCard.image)
        let demoJCB = UDirectoryServer(dsid: DirectoryServerInfo.demoJCB.rawValue, publicKey: DirectoryServerInfo.demoJCB.publicKey, keyID: DirectoryServerInfo.demoJCB.keyID, dsCACertificate: DirectoryServerInfo.demoJCB.caCert, providerName: "JCB", dsLogo: Asset.jcb.image)
        
        return [visa, discover, amex, mc, msigniaRSA, msigniaEC, demoMC, demoVisa, demoDiscover, demoAmex, demoCB, demoJCB, sandbox, sandbox2, mcMastercard, mcVisa, mcAmex, mcDiscover]
    }
    
    static func logo(forDSID dsID: String) -> UIImage? {
        let servers = USDKUtil.uDirectoryServers()
        for server in servers {
            if server.dsID == dsID {
                return server.dsLogo
            }
        }
        
        return nil
    }
}
